@@ -10,7 +10,7 @@
 #' @param x A [FBM][FBM-class].
 #' @param code A numeric vector (of length 256).
 #' You should construct it with `rep(NA_real_, 256)` and then replace the values
-#' which are of interest for you.
+#' which are of interest to you.
 #' @inheritParams FBM
 #'
 #' @examples
@@ -18,6 +18,7 @@
 #' X[] <- sample(as.raw(0:3), size = length(X), replace = TRUE)
 #' X[]
 #'
+#' # From an FBM of type 'raw' ('unsigned char')
 #' code <- rep(NA_real_, 256)
 #' code[1:3] <- c(1, 3, 5)
 #'
@@ -28,7 +29,7 @@
 #' X.code2 <- FBM.code256(10, 10, code, init = sample(as.raw(0:3), 100, TRUE))
 #' X.code2[]
 #'
-#' # Copy the FBM with another code
+#' # Get a new FBM.code256 object with another code (but same underlying data)
 #' X.code3 <- X.code$copy(code = rnorm(256))
 #' all.equal(X.code$code256, code)
 #'
@@ -123,46 +124,14 @@ add_code256 <- function(x, code) {
 
 ################################################################################
 
-#' Methods for the FBM.code256 class
-#'
-#' @name FBM.code256-methods
-#'
-#' @rdname FBM.code256-methods
-NULL
-
-#' Accessor method for class `FBM.code256`.
-#'
-#' @param x A [FBM.code256][FBM.code256-class].
-#' @inheritParams FBM-methods
-#'
-#' @rdname FBM.code256-methods
-#'
-#' @export
-#'
-setMethod(
-  '[', signature(x = "FBM.code256"),
-  Extract(
-    extract_vector = function(x, i) {
-      decodeVec(extractVec(x$address, i), x$code256)
-    },
-    extract_matrix = function(x, i, j) {
-      decodeMat(extractMat(x$address, i, j), x$code256)
-    }
-  )
-)
-
-################################################################################
-
-#' Counts
+#' Counts for class FBM.code256
 #'
 #' Counts by columns (or rows) the number of each unique element of a
 #' `FBM.code256`.
 #'
 #' @inheritParams bigstatsr-package
-#' @param byrow Count by rows rather than columns?
-#'   Default is `FALSE` (columns).
-#'
-#' @example examples/example-counts.R
+#' @param byrow Count by rows rather than by columns?
+#'   Default is `FALSE` (count by columns).
 #'
 #' @return A matrix of counts of K x m (or n) elements, where
 #' - K is the number of unique elements of the `BM.code`,
@@ -170,8 +139,21 @@ setMethod(
 #' - m is its number of columns.
 #'
 #' **Beware that K is up to 256. So, if you apply this on a Filebacked Big
-#' Matrix of one million columns, you will create a matrix of nearly 1GB!**.
+#' Matrix of one million columns, you will create a matrix of nearly 1GB!**
+#'
 #' @export
+#'
+#' @examples
+#' X <- big_attachExtdata()
+#' class(X)  # big_counts() is available for class FBM.code256 only
+#' X[1:5, 1:8]
+#'
+#' # by columns
+#' big_counts(X, ind.row = 1:5, ind.col = 1:8)
+#'
+#' # by rows
+#' big_counts(X, ind.row = 1:5, ind.col = 1:8, byrow = TRUE)
+#'
 big_counts <- function(X.code,
                        ind.row = rows_along(X.code),
                        ind.col = cols_along(X.code),
